# Pre-processing Sleepiness and Stress ratings

rm(list=ls())

## 0.Load Packages --------------------------------------------------------------

ipak <- function(pkg) {
  new.pkg <- pkg[!(pkg %in% installed.packages()[, "Package"])]
  if (length(new.pkg))
    install.packages(new.pkg, dependencies = T)
  sapply(pkg, require, character.only = T)
}
packages <- c("readr", "dplyr", "tidyverse", "ggplot2", 
              "ggpubr", "patchwork")
ipak(packages)

source("SCRIPT/util/palette_plot.R")

theme_set(theme_pubr(base_size = 12))

## 1.Load data --------------------------------------------------------------

d <- list.files(path = "DATA_RAW/data_exp", pattern = "*.csv", full.names = TRUE) %>% 
  map_df(~read_csv(.x) %>% mutate(condition = as.character(condition),
                                  session = as.character(session))) # Combine data sets into one data set 


## 2. Prep data --------------------------------------------------------------

#select columns of interest
dat <- d |>
  select(participant, condition, session, sleep_kb.keys, stress_slide.response)|>
  mutate(id = case_when(participant == "GNG87"~ "GNG84",
                        participant == "GN103"~ "GNG103",
                        participant == "GN100"~ "GNG100",
                        .default = participant),
         C = factor(case_when(condition == "CONDIZIONE FS" ~ "WR",
                              condition == "FF" ~ "WR",
                              condition == "fs" ~ "WR",
                              condition == "sd" ~ "SR",
                              condition == "FS" ~ "WR",
                              condition == "CONDIZIONE SD" ~ "SR",
                              condition == "SD" ~ "SR",
                              condition == " SD" ~ "SR",
                              condition == " FS" ~ "WR"
         )),
         S = factor(case_when(session == "SESSIONE 1" ~ 1,
                              session == 1 ~ 1,
                              session == "SESSIONE 2" ~ 2,
                              session == 2 ~ 2)))|>
  na.omit()


# Create Order Variable for session 2 analysis ----------------------
id_SD = subset(dat, C == "SR")|>
  select(id)|>
  unique()
id_FS = subset(dat, C == "WR" & S == 1)|>
  select(id)|>
  unique()

Order = rep("SR_WR",length(id_SD$id))
id_SD = cbind(id_SD, Order)
Order = rep("WR_WR",length(id_FS$id))
id_FS = cbind(id_FS, Order)

order_id = rbind(id_SD,id_FS)

# add data
dat = dat %>%
  left_join(.,order_id, by = "id")

# Exclude participants data --------------------------------------------

## Session 1
dat_clean_1 <- subset(dat, S == 1 &
                     # low ACC
                     id != "GNG38" & id != "GNG59" & id != "GNG102" &
                       #PSQI = 14 
                       id != "GNG82"&
                       # not respect sleep schedule
                       id != "GNG16" & 
                     id != "GNG21" & id != "GNG40" & 
                     id != "GNG46" & id != "GNG51" &
                     id != "GNG52"& id != "GNG58" &
                     id != "GNG65" & id != "GNG72" &
                     id != "GNG75" &  id != "GNG83"&
                     id != "GNG92" & id != "GNG95"&
                     id != "GNG96" & id != "GNG105")

## Session 2
dat_clean_2 <- subset(dat, S == 2 &
                        # low ACC
                        id != "GNG38" & id != "GNG59" & id != "GNG102" &
                        #PSQI = 14 
                        id != "GNG82"&
                        # not respect sleep schedule
                        id != "GNG16" & 
                        id != "GNG21" & id != "GNG40" & 
                        id != "GNG46" & id != "GNG51" &
                        id != "GNG52"& id != "GNG58" &
                        id != "GNG65" & id != "GNG72" &
                        id != "GNG75" &  id != "GNG83"&
                        id != "GNG92" & id != "GNG95"&
                        id != "GNG96" & id != "GNG105" &
                        #spec session 2
                        id != "GNG18" & id != "GNG29" &
                        id != "GNG34" & id != "GNG50")

dat_clean <- rbind(dat_clean_1,dat_clean_2)

# save!
write_csv(dat_clean, file = "DATA_OUT/SleepStress.csv")


# Plot Sleepiness -------------------------------------
p_sleep <- dat_clean %>% 
  dplyr::group_by(participant,Order) %>%
  ggplot(aes(x = Order, 
             y = sleep_kb.keys, color = Order))+
  geom_jitter(width = 0.1, alpha = 0.6, size = 2.5,
              show.legend = FALSE)+
  stat_summary(fun=mean, geom="point", shape=15, size=1.5,
               color="black")+
  stat_summary(
  geom= "errorbar",
  width = 0.1,
  size = 1,
  color = "black", alpha = 1)+
  scale_color_manual(values = rev(pal_okabe_ito_2))+
  ylab("sleepiness")+
  xlab(" ")+
  facet_wrap(~ S)

# Plot Stress
p_stress <-dat_clean %>% 
  dplyr::group_by(participant,Order) %>%
  ggplot(aes(x = Order, 
             y = stress_slide.response, color = Order))+
  geom_jitter(width = 0.1, alpha = 0.6, size = 2.5,
              show.legend = FALSE)+
  stat_summary(fun=mean, geom="point", shape=15, size=1.5,
               color="black")+
  stat_summary(
    geom= "errorbar",
    width = 0.1,
    size = 1,
    color = "black", alpha = 1)+
  scale_color_manual(values = rev(pal_okabe_ito_2))+
  ylab("stress")+
  xlab("Group")+
  facet_wrap(~ S)

tiff("PLOT/SleepStress.png",
     width = 15, height = 16, units = 'cm', res = 300,
     compression = 'lzw')
p_sleep/p_stress
dev.off()
















